//This is an abstract class of a generic object to draw.

#ifndef __FILEWINDOW_H__
#define __FILEWINDOW_H__

#include <FL/gl.h>
#include <FL/glut.h>
#include <stdio.h>
#include <stdlib.h>
#include <string>
#include <vector>
#include "Icon.h"
#include "dir.h"
#include "textureLoader.h"

//this is the percentage of the window the title takes
#define TITLEBAR_HEIGHT 0.05

//this is the space between each icon
#define ICON_SPACING 0.2

//this is the number of icons on one line
#define ICON_COLS 4.0

//this is how much space is between the edges of the 
//titlebar and the text for horzontal and vertical.
#define TITLEBAR_HPADDING 0.15
#define TITLEBAR_VPADDING 0.05

using namespace std;

class FileWindow {
 public:
  ////////////////
  //Constructor //
  ////////////////
  FileWindow();

  FileWindow(string dir, float w, float h, float x, float y, float z);

  //////////////
  //Mutators: //
  //////////////
  //move the object's center point in space
  void x(float);
  void y(float);
  void z(float);

  //change the size of the object
  void setWidth(float);
  void setHeight(float);

  //sets the current directory this displays
  void setDir(string dir);

  //sets one window to be the index of the current directory
  bool isIndex;

  //set if the file window should display the active colors.
  bool isCurrent;

  //////////////
  //Getters:  //
  //////////////
  //get the object's center point in space
  float x(void);
  float y(void);
  float z(void);
 
  //get the size of the object
  float getWidth(void);
  float getHeight(void);

  string getDir(void);

  //////////////
  // Events:  //
  //////////////
  //returns empty if not clicked or if action was already taken.
  //otherwise returns the directory chosen. 
  string onClick(int button, vector<void*> pickStacks, uint depth);

  //////////////
  // The Rest://
  //////////////
  void draw(void);

 protected:

 private:
  void loadIcons(void);
  void scrollIcons(int amount);

  //the center point
  float centerx, centery, centerz;

  //the size
  float width, height;

  //this is the list of icons inside the window
  vector<Icon*> icons;

  //this is the top-left icon displayed from the list
  uint currentIcon;

  float iconwidth;

  //this holds the directory this window displays
  string directory;

  //this are the colors of the window elements
  static float background[4];
  static float titlebar[4];
  static float indextitlebar[4];
  static float titlebartext[4];
  static float activetitlebar[4];
  static float activebackground[4];
  static float activeindextitlebar[4];

  static GLuint winTexture;
  static GLuint barTexture;
};


#endif
